@@ -1,7 +1,7 @@
 package Data::Clean;
 
 our $DATE = '2017-01-14'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use Log::Any::IfLOG '$log';
 
 sub new {
     my ($class, %opts) = @_;
-    my $self = bless {opts=>\%opts}, $class;
+    my $self = bless {_opts=>\%opts}, $class;
     $log->tracef("Cleanser options: %s", \%opts);
 
     my $cd = $self->_generate_cleanser_code;
@@ -106,14 +106,13 @@ sub command_die {
 
 sub _generate_cleanser_code {
     my $self = shift;
-    my $opts = $self->{opts};
+    my $opts = $self->{_opts};
 
     # compilation data, a structure that will be passed around between routines
     # during the generation of cleanser code.
     my $cd = {
         modules => {}, # key = module name, val = version
-        clone_func   => $self->{'!clone_func'},
-        unbless_func => $self->{'!unbless_func'},
+        clone_func   => $self->{_opts}{'!clone_func'},
         code => '',
     };
 
@@ -292,7 +291,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.47 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-14.
+This document describes version 0.48 of Data::Clean (from Perl distribution Data-Clean), released on 2017-01-14.
 
 =head1 SYNOPSIS
 
